<?php

namespace Asadi\Admission\Http\Controllers;
use Litepie\Admission\Http\Requests\AdmissionRequest;
use Litepie\Admission\Models\Admission;

trait AdmissionWorkflow {
	
    /**
     * Workflow controller function for admission.
     *
     * @param Model   $admission
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(AdmissionRequest $request, Admission $admission, $step)
    {

        try {

            $admission->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('admission::admission.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/admission/admission/' . $admission->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/admission/admission/' . $admission->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for admission.
     *
     * @param Model   $admission
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Admission $admission, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $admission->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('admission::admission.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('admission::admin.admission.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('admission::admin.admission.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('admission::admin.admission.message', $data)->render();

        }

    }
}