<?php

namespace Asadi\Admission\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Admission\Interfaces\AdmissionRepositoryInterface;
use Asadi\Admission\Repositories\Presenter\AdmissionItemTransformer;

/**
 * Pubic API controller class.
 */
class AdmissionPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Admission\Interfaces\AdmissionRepositoryInterface $admission
     *
     * @return type
     */
    public function __construct(AdmissionRepositoryInterface $admission)
    {
        $this->repository = $admission;
        parent::__construct();
    }

    /**
     * Show admission's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $admissions = $this->repository
            ->setPresenter('\\Asadi\\Admission\\Repositories\\Presenter\\AdmissionListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $admissions['code'] = 2000;
        return response()->json($admissions)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show admission.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $admission = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($admission)) {
            $admission         = $this->itemPresenter($module, new AdmissionItemTransformer);
            $admission['code'] = 2001;
            return response()->json($admission)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
