<?php

namespace Asadi\Admission\Policies;

use App\User;
use Asadi\Admission\Models\Admission;

class AdmissionPolicy
{

    /**
     * Determine if the given user can view the admission.
     *
     * @param User $user
     * @param Admission $admission
     *
     * @return bool
     */
    public function view(User $user, Admission $admission)
    {
        if ($user->canDo('admission.admission.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $admission->user_id;
    }

    /**
     * Determine if the given user can create a admission.
     *
     * @param User $user
     * @param Admission $admission
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('admission.admission.create');
    }

    /**
     * Determine if the given user can update the given admission.
     *
     * @param User $user
     * @param Admission $admission
     *
     * @return bool
     */
    public function update(User $user, Admission $admission)
    {
        if ($user->canDo('admission.admission.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $admission->user_id;
    }

    /**
     * Determine if the given user can delete the given admission.
     *
     * @param User $user
     * @param Admission $admission
     *
     * @return bool
     */
    public function destroy(User $user, Admission $admission)
    {
        if ($user->canDo('admission.admission.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $admission->user_id;
    }

    /**
     * Determine if the given user can verify the given admission.
     *
     * @param User $user
     * @param Admission $admission
     *
     * @return bool
     */
    public function verify(User $user, Admission $admission)
    {
        if ($user->canDo('admission.admission.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('admission.admission.verify') 
        && $user->is('manager')
        && $admission->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given admission.
     *
     * @param User $user
     * @param Admission $admission
     *
     * @return bool
     */
    public function approve(User $user, Admission $admission)
    {
        if ($user->canDo('admission.admission.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
