<?php

namespace Asadi\Admission\Providers;

use Illuminate\Support\ServiceProvider;

class AdmissionServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'admission');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'admission');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('admission', function ($app) {
            return $this->app->make('Asadi\Admission\Admission');
        });

        // Bind Admission to repository
        $this->app->bind(
            'Asadi\Admission\Interfaces\AdmissionRepositoryInterface',
            \Asadi\Admission\Repositories\Eloquent\AdmissionRepository::class
        );

        $this->app->register(\Asadi\Admission\Providers\AuthServiceProvider::class);
        $this->app->register(\Asadi\Admission\Providers\EventServiceProvider::class);
        $this->app->register(\Asadi\Admission\Providers\RouteServiceProvider::class);
        // $this->app->register(\Asadi\Admission\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['admission'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('asadi/admission.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/admission')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/admission')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
