<?php

namespace Asadi\Admission\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Asadi\Admission\Models\Admission;

class AdmissionAction
{
    /**
     * Perform the complete action.
     *
     * @param Admission $admission
     *
     * @return Admission
     */
    public function complete(Admission $admission)
    {
        try {
            $admission->status = 'complete';
            return $admission->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Admission $admission
     *
     * @return Admission
     */public function verify(Admission $admission)
    {
        try {
            $admission->status = 'verify';
            return $admission->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Admission $admission
     *
     * @return Admission
     */public function approve(Admission $admission)
    {
        try {
            $admission->status = 'approve';
            return $admission->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Admission $admission
     *
     * @return Admission
     */public function publish(Admission $admission)
    {
        try {
            $admission->status = 'publish';
            return $admission->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Admission $admission
     *
     * @return Admission
     */
    public function archive(Admission $admission)
    {
        try {
            $admission->status = 'archive';
            return $admission->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Admission $admission
     *
     * @return Admission
     */
    public function unpublish(Admission $admission)
    {
        try {
            $admission->status = 'unpublish';
            return $admission->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
