<?php

namespace Asadi\Admission\Workflow;

use Asadi\Admission\Models\Admission;
use Validator;

class AdmissionValidator
{

    /**
     * Determine if the given admission is valid for complete status.
     *
     * @param Admission $admission
     *
     * @return bool / Validator
     */
    public function complete(Admission $admission)
    {
        return Validator::make($admission->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given admission is valid for verify status.
     *
     * @param Admission $admission
     *
     * @return bool / Validator
     */
    public function verify(Admission $admission)
    {
        return Validator::make($admission->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given admission is valid for approve status.
     *
     * @param Admission $admission
     *
     * @return bool / Validator
     */
    public function approve(Admission $admission)
    {
        return Validator::make($admission->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given admission is valid for publish status.
     *
     * @param Admission $admission
     *
     * @return bool / Validator
     */
    public function publish(Admission $admission)
    {
        return Validator::make($admission->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given admission is valid for archive status.
     *
     * @param Admission $admission
     *
     * @return bool / Validator
     */
    public function archive(Admission $admission)
    {
        return Validator::make($admission->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given admission is valid for unpublish status.
     *
     * @param Admission $admission
     *
     * @return bool / Validator
     */
    public function unpublish(Admission $admission)
    {
        return Validator::make($admission->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
